"""Real-time monitoring of Celery workers."""

from __future__ import absolute_import

VERSION = (0, 5, 0)

__version__ = ".".join(map(str, VERSION))
__author__ = "Ask Solem"
__contact__ = "ask@celeryproject.org"
__homepage__ = "http://github.com/celery/celerymon/"
__docformat__ = "restructuredtext"
